@@ -78,6 +78,13 @@ You should have also already run bin/buildout.""",
         ns['frame'] = frame
         
         # frame.SetMenuBar(menuBar)
+        
+        # set the app icon
+        mypath = os.path.dirname(__file__)
+        iconFile = os.path.join(mypath, 'images', 'plone.ico')
+        icon1 = wx.Icon(iconFile, wx.BITMAP_TYPE_ICO)
+        frame.SetIcon(icon1)
+        
         frame.Show(True)
         frame.Bind(wx.EVT_CLOSE, self.OnCloseFrame)
 
@@ -156,6 +163,9 @@ def main():
     if (len(args) == 0) and os.path.exists('buildout.cfg'):
         config_file = 'buildout.cfg'
         installed_file = '.installed.cfg'
+    elif (len(args) == 0) and os.path.exists('../buildout.cfg'):
+        config_file = '../buildout.cfg'
+        installed_file = '../.installed.cfg'
     elif (len(args) == 1) and os.path.exists(args[0]):
         config_file = args[0]
         installed_file = '.installed.cfg'
